==> jc-1.4.0.tar.gz: javax/naming/spi/DirStateFactory__24Result.c <==
// public class javax.naming.spi.DirStateFactory$Result

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 95ab7af9d6eaf0b3 javax_naming_directory_Attributes
// @dep_class 19a405366ff0e296 javax_naming_spi_DirStateFactory
// @dep_class 65a7e091dbe07693 javax_naming_spi_DirStateFactory__24Result

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_naming_directory_Attributes
// @dep_header javax_naming_spi_DirStateFactory
// @dep_header javax_naming_spi_DirStateFactory__24Result

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/naming/directory/Attributes.h"
#include "javax/naming/spi/DirStateFactory.h"
#include "javax/naming/spi/DirStateFactory__24Result.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.Object obj
static _jc_field _jc_javax_naming_spi_DirStateFactory__24Result$field_info$obj = {
	.name=		"obj",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_spi_DirStateFactory__24Result$object, refs[-1].javax_naming_spi_DirStateFactory__24Result.obj),
};

// private javax.naming.directory.Attributes outAttrs
static _jc_field _jc_javax_naming_spi_DirStateFactory__24Result$field_info$outAttrs = {
	.name=		"outAttrs",
	.signature=	"Ljavax/naming/directory/Attributes;",
	.class=		&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.type=		&_jc_javax_naming_directory_Attributes$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_spi_DirStateFactory__24Result$object, refs[-1].javax_naming_spi_DirStateFactory__24Result.outAttrs),
};

// Fields
static _jc_field *const _jc_javax_naming_spi_DirStateFactory__24Result$fields[] = {
	&_jc_javax_naming_spi_DirStateFactory__24Result$field_info$obj,
	&_jc_javax_naming_spi_DirStateFactory__24Result$field_info$outAttrs
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object, javax.naming.directory.Attributes)
//

static _jc_linenum _jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$_init$0db9fd592f801ffe[];

static const unsigned char _jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$_init$0db9fd592f801ffe[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_naming_spi_DirStateFactory__24Result$param_types$_init$0db9fd592f801ffe[] = {
	&_jc_java_lang_Object$type,
	&_jc_javax_naming_directory_Attributes$type
};

_jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$_init$0db9fd592f801ffe = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;Ljavax/naming/directory/Attributes;)V",
	.class=			&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.param_types=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_types$_init$0db9fd592f801ffe,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$_init$0db9fd592f801ffe,
	.signature_hash=	_JC_JLONG(0xdb9fd592f801ffe),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_spi_DirStateFactory__24Result$method$_init$0db9fd592f801ffe,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$_init$0db9fd592f801ffe
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_spi_DirStateFactory__24Result, _init$0db9fd592f801ffe);

void
_jc_javax_naming_spi_DirStateFactory__24Result$method$_init$0db9fd592f801ffe(_jc_env *const env, _jc_javax_naming_spi_DirStateFactory__24Result$object *this, _jc_java_lang_Object$object *param0, _jc_object *param1)
{
	struct _jc_javax_naming_spi_DirStateFactory__24Result$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(63);				// 0
	_JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, obj) = r1;
	_JC_LINE_NUMBER(64);				// 1
	_JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, outAttrs) = r2;
	_JC_LINE_NUMBER(65);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.naming.directory.Attributes getAttributes()
//

static _jc_linenum _jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getAttributes$de01e608f1e92b33[];

static const unsigned char _jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getAttributes$de01e608f1e92b33[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getAttributes$de01e608f1e92b33 = {
	.name=			"getAttributes",
	.signature=		"()Ljavax/naming/directory/Attributes;",
	.class=			&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.return_type=		&_jc_javax_naming_directory_Attributes$type,
	.param_ptypes=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getAttributes$de01e608f1e92b33,
	.signature_hash=	_JC_JLONG(0xde01e608f1e92b33),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable, javax_naming_spi_DirStateFactory__24Result.getAttributes$de01e608f1e92b33) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getAttributes$de01e608f1e92b33
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_spi_DirStateFactory__24Result, getAttributes$de01e608f1e92b33);

_jc_object *
_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33(_jc_env *const env, _jc_javax_naming_spi_DirStateFactory__24Result$object *this)
{
	struct _jc_javax_naming_spi_DirStateFactory__24Result$object *r0;
	struct _jc_object *r1;

	r0 = this;
	_JC_LINE_NUMBER(74);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, outAttrs);
	return r1;
}

//
// public java.lang.Object getObject()
//

static _jc_linenum _jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getObject$3a2eec332ceac060[];

static const unsigned char _jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getObject$3a2eec332ceac060[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getObject$3a2eec332ceac060 = {
	.name=			"getObject",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getObject$3a2eec332ceac060,
	.signature_hash=	_JC_JLONG(0x3a2eec332ceac060),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable, javax_naming_spi_DirStateFactory__24Result.getObject$3a2eec332ceac060) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getObject$3a2eec332ceac060
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_spi_DirStateFactory__24Result, getObject$3a2eec332ceac060);

_jc_java_lang_Object$object *
_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060(_jc_env *const env, _jc_javax_naming_spi_DirStateFactory__24Result$object *this)
{
	struct _jc_javax_naming_spi_DirStateFactory__24Result$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(69);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, obj);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_naming_spi_DirStateFactory__24Result$methods[] = {
	&_jc_javax_naming_spi_DirStateFactory__24Result$method_info$_init$0db9fd592f801ffe,
	&_jc_javax_naming_spi_DirStateFactory__24Result$method_info$getAttributes$de01e608f1e92b33,
	&_jc_javax_naming_spi_DirStateFactory__24Result$method_info$getObject$3a2eec332ceac060
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_19[] = {
	&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[19]=	_jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_19,
	[113]=	_jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_naming_spi_DirStateFactory__24Result$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "javax/naming/directory/Attributes",	_JC_JLONG(0x95ab7af9d6eaf0b3) },
	{ "javax/naming/spi/DirStateFactory",	_JC_JLONG(0x19a405366ff0e296) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_naming_spi_DirStateFactory__24Result$vtype _jc_javax_naming_spi_DirStateFactory__24Result$type = {
    .type= {
	.name=			"javax/naming/spi/DirStateFactory$Result",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x65a7e091dbe07693),
		.source_file=		"DirStateFactory.java",
		.instance_size=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$refs) + sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$fields) / sizeof(*_jc_javax_naming_spi_DirStateFactory__24Result$fields),
		.fields=		_jc_javax_naming_spi_DirStateFactory__24Result$fields,
		.num_methods=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$methods) / sizeof(*_jc_javax_naming_spi_DirStateFactory__24Result$methods),
		.methods=		_jc_javax_naming_spi_DirStateFactory__24Result$methods,
		.instanceof_hash_table=	_jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_table,
		.outer_class=		&_jc_javax_naming_spi_DirStateFactory$type,
		.num_class_depends=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$class_depends) / sizeof(*_jc_javax_naming_spi_DirStateFactory__24Result$class_depends),
		.class_depends=		_jc_javax_naming_spi_DirStateFactory__24Result$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_naming_spi_DirStateFactory__24Result= {
	    .getAttributes$de01e608f1e92b33=
		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33,
	    .getObject$3a2eec332ceac060=
		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060,
	},
    }
};

==> jc-1.4.5.tar.gz: javax/naming/spi/DirStateFactory__24Result.c <==
// public class javax.naming.spi.DirStateFactory$Result

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 95ab7af9d6eaf0b3 javax_naming_directory_Attributes
// @dep_class 19a405366ff0e296 javax_naming_spi_DirStateFactory
// @dep_class 65a7e091dbe07693 javax_naming_spi_DirStateFactory__24Result

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header javax_naming_directory_Attributes
// @dep_header javax_naming_spi_DirStateFactory
// @dep_header javax_naming_spi_DirStateFactory__24Result

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "javax/naming/directory/Attributes.h"
#include "javax/naming/spi/DirStateFactory.h"
#include "javax/naming/spi/DirStateFactory__24Result.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// private java.lang.Object obj
static _jc_field _jc_javax_naming_spi_DirStateFactory__24Result$field_info$obj = {
	.name=		"obj",
	.signature=	"Ljava/lang/Object;",
	.class=		&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.type=		&_jc_java_lang_Object$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_spi_DirStateFactory__24Result$object, refs[-1].javax_naming_spi_DirStateFactory__24Result.obj),
};

// private javax.naming.directory.Attributes outAttrs
static _jc_field _jc_javax_naming_spi_DirStateFactory__24Result$field_info$outAttrs = {
	.name=		"outAttrs",
	.signature=	"Ljavax/naming/directory/Attributes;",
	.class=		&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.type=		&_jc_javax_naming_directory_Attributes$type,
	.access_flags=	_JC_ACC_PRIVATE,
	.offset=	_JC_OFFSETOF(_jc_javax_naming_spi_DirStateFactory__24Result$object, refs[-1].javax_naming_spi_DirStateFactory__24Result.outAttrs),
};

// Fields
static _jc_field *const _jc_javax_naming_spi_DirStateFactory__24Result$fields[] = {
	&_jc_javax_naming_spi_DirStateFactory__24Result$field_info$obj,
	&_jc_javax_naming_spi_DirStateFactory__24Result$field_info$outAttrs
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// public void <init>(java.lang.Object, javax.naming.directory.Attributes)
//

static _jc_linenum _jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$_init$0db9fd592f801ffe[];

static const unsigned char _jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$_init$0db9fd592f801ffe[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_javax_naming_spi_DirStateFactory__24Result$param_types$_init$0db9fd592f801ffe[] = {
	&_jc_java_lang_Object$type,
	&_jc_javax_naming_directory_Attributes$type
};

_jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$_init$0db9fd592f801ffe = {
	.name=			"<init>",
	.signature=		"(Ljava/lang/Object;Ljavax/naming/directory/Attributes;)V",
	.class=			&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.param_types=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_types$_init$0db9fd592f801ffe,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$_init$0db9fd592f801ffe,
	.signature_hash=	_JC_JLONG(0xdb9fd592f801ffe),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_spi_DirStateFactory__24Result$method$_init$0db9fd592f801ffe,
	.num_parameters=	2,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	3,
	      .table=	_jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$_init$0db9fd592f801ffe
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_spi_DirStateFactory__24Result, _init$0db9fd592f801ffe);

void _JC_JCNI_ATTR
_jc_javax_naming_spi_DirStateFactory__24Result$method$_init$0db9fd592f801ffe(_jc_env *const env, _jc_javax_naming_spi_DirStateFactory__24Result$object *this, _jc_java_lang_Object$object *param0, _jc_object *param1)
{
	struct _jc_javax_naming_spi_DirStateFactory__24Result$object *r0;
	struct _jc_java_lang_Object$object *r1;
	struct _jc_object *r2;

	r0 = this;
	r1 = param0;
	r2 = param1;
	_JC_LINE_NUMBER(63);				// 0
	_JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, obj) = r1;
	_JC_LINE_NUMBER(64);				// 1
	_JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, outAttrs) = r2;
	_JC_LINE_NUMBER(65);				// 2
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public javax.naming.directory.Attributes getAttributes()
//

static _jc_linenum _jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getAttributes$de01e608f1e92b33[];

static const unsigned char _jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getAttributes$de01e608f1e92b33[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getAttributes$de01e608f1e92b33 = {
	.name=			"getAttributes",
	.signature=		"()Ljavax/naming/directory/Attributes;",
	.class=			&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.return_type=		&_jc_javax_naming_directory_Attributes$type,
	.param_ptypes=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getAttributes$de01e608f1e92b33,
	.signature_hash=	_JC_JLONG(0xde01e608f1e92b33),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable, javax_naming_spi_DirStateFactory__24Result.getAttributes$de01e608f1e92b33) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getAttributes$de01e608f1e92b33
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_spi_DirStateFactory__24Result, getAttributes$de01e608f1e92b33);

_jc_object * _JC_JCNI_ATTR
_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33(_jc_env *const env, _jc_javax_naming_spi_DirStateFactory__24Result$object *this)
{
	struct _jc_javax_naming_spi_DirStateFactory__24Result$object *r0;
	struct _jc_object *r1;

	r0 = this;
	_JC_LINE_NUMBER(74);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, outAttrs);
	return r1;
}

//
// public java.lang.Object getObject()
//

static _jc_linenum _jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getObject$3a2eec332ceac060[];

static const unsigned char _jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getObject$3a2eec332ceac060[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_javax_naming_spi_DirStateFactory__24Result$method_info$getObject$3a2eec332ceac060 = {
	.name=			"getObject",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_javax_naming_spi_DirStateFactory__24Result$param_ptypes$getObject$3a2eec332ceac060,
	.signature_hash=	_JC_JLONG(0x3a2eec332ceac060),
	.access_flags=		_JC_ACC_PUBLIC,
	.function=		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060,
	.vtable_index=		_JC_OFFSETOF(struct _jc_javax_naming_spi_DirStateFactory__24Result$vtable, javax_naming_spi_DirStateFactory__24Result.getObject$3a2eec332ceac060) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_javax_naming_spi_DirStateFactory__24Result$linenum_table$getObject$3a2eec332ceac060
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(javax_naming_spi_DirStateFactory__24Result, getObject$3a2eec332ceac060);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060(_jc_env *const env, _jc_javax_naming_spi_DirStateFactory__24Result$object *this)
{
	struct _jc_javax_naming_spi_DirStateFactory__24Result$object *r0;
	struct _jc_java_lang_Object$object *r1;

	r0 = this;
	_JC_LINE_NUMBER(69);				// 0
	r1 = _JC_REF_FIELD(env, r0, javax_naming_spi_DirStateFactory__24Result, obj);
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_javax_naming_spi_DirStateFactory__24Result$methods[] = {
	&_jc_javax_naming_spi_DirStateFactory__24Result$method_info$_init$0db9fd592f801ffe,
	&_jc_javax_naming_spi_DirStateFactory__24Result$method_info$getAttributes$de01e608f1e92b33,
	&_jc_javax_naming_spi_DirStateFactory__24Result$method_info$getObject$3a2eec332ceac060
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_19[] = {
	&_jc_javax_naming_spi_DirStateFactory__24Result$type,
	_JC_NULL
};
static _jc_type *const _jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[19]=	_jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_19,
	[101]=	_jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_javax_naming_spi_DirStateFactory__24Result$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "javax/naming/directory/Attributes",	_JC_JLONG(0x95ab7af9d6eaf0b3) },
	{ "javax/naming/spi/DirStateFactory",	_JC_JLONG(0x19a405366ff0e296) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_javax_naming_spi_DirStateFactory__24Result$vtype _jc_javax_naming_spi_DirStateFactory__24Result$type = {
    .type= {
	.name=			"javax/naming/spi/DirStateFactory$Result",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_PUBLIC,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0x65a7e091dbe07693),
		.source_file=		"DirStateFactory.java",
		.instance_size=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$refs) + sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$object),
		.num_virtual_refs=	2,
		.num_fields=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$fields) / sizeof(*_jc_javax_naming_spi_DirStateFactory__24Result$fields),
		.fields=		_jc_javax_naming_spi_DirStateFactory__24Result$fields,
		.num_methods=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$methods) / sizeof(*_jc_javax_naming_spi_DirStateFactory__24Result$methods),
		.methods=		_jc_javax_naming_spi_DirStateFactory__24Result$methods,
		.instanceof_hash_table=	_jc_javax_naming_spi_DirStateFactory__24Result$instanceof_hash_table,
		.outer_class=		&_jc_javax_naming_spi_DirStateFactory$type,
		.num_class_depends=		sizeof(_jc_javax_naming_spi_DirStateFactory__24Result$class_depends) / sizeof(*_jc_javax_naming_spi_DirStateFactory__24Result$class_depends),
		.class_depends=		_jc_javax_naming_spi_DirStateFactory__24Result$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.javax_naming_spi_DirStateFactory__24Result= {
	    .getAttributes$de01e608f1e92b33=
		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getAttributes$de01e608f1e92b33,
	    .getObject$3a2eec332ceac060=
		&_jc_javax_naming_spi_DirStateFactory__24Result$method$getObject$3a2eec332ceac060,
	},
    }
};
